# python3.8+ Toolkit for personal use

## Install

```bash
pip install toolkit_cmm
```

## Quick Start

```py
from toolkit_cmm.helloworld import hello_world;
print(hello_world())
```

## Docs

<https://cromarmot.github.io/pytoolkit>
